@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.81 2004/07/22 17:39:50 sampie Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.86 2004/12/01 16:32:21 richb Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -30,25 +30,13 @@
 
 time_t time();
 
+static void init_buttons();
 static void init_text();
 
 double max_fix[MAXBASES] = {
     6.871947674e+10, 3.245185537e+32, 1.000000000e+36, 2.230074520e+43
 };
 
-double min_fix[MAXACC][MAXBASES] = {
-    { 2.500000000e-1, 3.750000000e-1, 1.000000000e-1,  4.375000000e-1 },
-    { 1.250000000e-1, 4.687500000e-2, 1.000000000e-2,  2.734375000e-2 },
-    { 6.250000000e-2, 5.859375000e-3, 1.000000000e-3,  1.708984375e-3 },
-    { 3.125000000e-2, 7.324218750e-4, 1.000000000e-4,  1.068115234e-4 },
-    { 1.562500000e-2, 9.155273437e-5, 1.000000000e-5,  6.675720215e-6 },
-    { 7.812500000e-3, 1.144409180e-5, 1.000000000e-6,  4.172325134e-7 },
-    { 6.906250000e-3, 1.430511475e-6, 1.000000000e-7,  2.607703209e-8 },
-    { 1.953125000e-3, 1.788139343e-7, 1.000000000e-8,  1.629814506e-9 },
-    { 9.765625000e-4, 2.235174179e-8, 1.000000000e-9,  1.018634066e-10 },
-    { 4.882812500e-4, 2.793967724e-9, 1.000000000e-10, 6.366462912e-12 }
-};
-
 char *base_str[]  = {          /* Strings for each base value. */
     N_("_Bin"), N_("_Oct"), N_("_Dec"), N_("He_x")
 };
@@ -61,7 +49,7 @@ char *base_desc[]  = {         /* Tooltips for each base value. */
 };
 
 char *calc_res[] = {
-    "accuracy", "base", "display", "mode", "showregisters", "trigtype",
+    "accuracy", "base", "display", "modetype", "showregisters", "trigtype",
     "showzeroes", "showthousands", "syntax"
 };
 
@@ -78,13 +66,9 @@ char *dtype_desc[] = {         /* Tooltips for each display mode value. */
 char *hyp_desc = N_("Set hyperbolic option for trigonometric functions");
 char *inv_desc = N_("Set inverse option for trigonometric functions");
 
-char *mode_str[]  = {          /* Strings for each mode value. */
-    N_("BASIC"), N_("FINANCIAL"), N_("SCIENTIFIC"), N_("SCIENTIFIC_EXP")
-};
-
 char *mstrs[] = {              /* Mode titles to be added to the titlebar. */
-    N_("Basic Mode"), N_("Financial Mode"), 
-    N_("Scientific Mode"), N_("Expression Mode")
+    N_("Basic"), N_("Advanced"), N_("Financial"), 
+    N_("Scientific"), N_("Expression")
 };
 
 char *ttype_str[] = {          /* Strings for each trig type value. */
@@ -105,8 +89,8 @@ int basevals[4] = { 2, 8, 10, 16 };
 
 char *Rbstr[MAXBASES]     = { "BIN", "OCT", "DEC", "HEX" };
 char *Rdstr[MAXDISPMODES] = { "ENG", "FIX", "SCI" };
-char *Rmstr[MAXMODES]     = { "BASIC", "FINANCIAL", 
-                              "SCIENTIFIC", "SCIENTIFIC_EXP" };
+char *Rmstr[MAXMODES]     = { "BASIC", "ADVANCED", "FINANCIAL", 
+                              "SCIENTIFIC" };
 char *Rtstr[MAXTRIGMODES] = { "DEG", "GRAD", "RAD" };
 char *Rsstr[MAXSYNTAX]    = { "ARITHMETIC", "ARITHMETIC_PRECEDENCE" };
 
@@ -129,7 +113,9 @@ Vars v;            /* Calctool variables and options. */
  *-----------+-----------------------------------------------------
  */
 
-struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
+struct button b_buttons[B_NOBUTTONS];      /* Buttons for "Basic" mode. */
+
+struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
 
 /* str
    hstr
@@ -1149,6 +1135,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 },
 };
 
+
 void
 do_calctool(int argc, char **argv)
 {
@@ -1157,6 +1144,8 @@ do_calctool(int argc, char **argv)
 
     build_word_map();          /* Initialize i18n. */
 
+    init_buttons();            /* Setup the buttons for "Basic" mode. */
+
     v->progname = argv[0];     /* Save programs name. */
     v->appname  = NULL;
 
@@ -1238,6 +1227,25 @@ doerr(char *errmes)
 }
 
 
+static int b_buttons_n[B_NOBUTTONS] = {
+    5,  6,  7,  13,     /* Bksp  CE  Clr  +/- */
+    0,  1,  2,  3,      /*  7    8    9    /  */
+    8,  9,  10, 11,     /*  4    5    6    *  */
+    16, 17, 18, 19,     /*  1    2    3    -  */
+    24, 25, 26, 27,     /*  0    .    =    +  */
+};
+
+static void
+init_buttons()         /* Setup buttons for "Basic" mode. */
+{
+    int i;
+
+    for (i = 0; i < B_NOBUTTONS; i++) {
+        b_buttons[i] = a_buttons[b_buttons_n[i]];
+    }
+}
+
+
 static void
 init_text()         /* Setup constant strings. */
 {
